config

package
v0.0.0-...-345fb63 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 30, 2021 License: GPL-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Copy

func Copy(src, dst string) error

Copy the src file to dst. Any existing file will be overwritten and will not copy file attributes. Source: https://stackoverflow.com/questions/21060945/simple-way-to-copy-a-file

func GetCurrentPath

func GetCurrentPath() (string, error)

GetCurrentPath Getting P2PRC Directory from environment variable

func GetPathP2PRC

func GetPathP2PRC() (string, error)

GetPathP2PRC Getting P2PRC Directory from environment variable

func SetDefaults

func SetDefaults() error

SetDefaults This function to be called only during a make install

Types

type Config

type Config struct {
	IPTable                  string
	DockerContainers         string
	DefaultDockerFile        string
	SpeedTestFile            string
	IPV6Address              string
	PluginPath               string
	TrackContainersPath      string
	ServerPort               string
	GroupTrackContainersPath string
}

func ConfigInit

func ConfigInit() (*Config, error)

Jump to