Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Copy ¶
Copy the src file to dst. Any existing file will be overwritten and will not copy file attributes. Source: https://stackoverflow.com/questions/21060945/simple-way-to-copy-a-file
func GetCurrentPath ¶
GetCurrentPath Getting P2PRC Directory from environment variable
func GetPathP2PRC ¶
GetPathP2PRC Getting P2PRC Directory from environment variable
func SetDefaults ¶
func SetDefaults() error
SetDefaults This function to be called only during a make install
Types ¶
Click to show internal directories.
Click to hide internal directories.